@@ -219,17 +219,17 @@ def send_mail(subject, verbose):
 
     context = ssl.create_default_context()
     print("Sending mail...")
-    #try:
-    with smtplib.SMTP_SSL(smtp_server, email_smtp_port, context=context) as server:
-        server.login(sender_email, email_password)
+    try:
+        with smtplib.SMTP_SSL(smtp_server, email_smtp_port, context=context) as server:
+            server.login(sender_email, email_password)
 
-        server.sendmail(sender_email, receiver_email, message).encode('utf-8')
+            server.sendmail(sender_email, receiver_email, message.encode("utf8"))
 
-        print("Successful sending mail")
+            print("Successful sending mail")
 
-    #except:
-        #print(f"Sending error please check the sender's email ({sender_email}) and password or the receiver's "
-              #f"({receiver_email})")
+    except:
+        print(f"Sending error please check the sender's email ({sender_email}) and password or the receiver's "
+              f"({receiver_email})")
 
 
 def daemon():
