@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 import uacs
 import os
@@ -7,7 +8,7 @@ import sys
 uid = os.getuid()
 
 sys.stdout = open(os.devnull, 'w')
-uacs.restore(True)
+uacs.restore(False)
 
 if uid != 0:
     print("\033[1mYou must be root for execute this program")
@@ -50,17 +51,11 @@ if str(sys.argv[command]) == "append":
     except:
         print("commande usage: uacs append 'service_to_append'")
 
-elif str(sys.argv[command]) == "--help" or str(sys.argv[command]) == "-h":
-    sys.stdout = sys.__stdout__
-    docs = open("docs/help.txt", "r")
-    print(docs.read())
-    docs.close()
-
 elif str(sys.argv[command]) == "start":
     uacs.run_daemon()
 
 elif str(sys.argv[command]) == "send_mail":
-    uacs.send_mail("test", verbose)
+    uacs.send_mail("ultimate_auto_check_service", verbose)
 
 elif str(sys.argv[command]) == "restore":
     uacs.restore(verbose)
@@ -77,4 +72,26 @@ elif str(sys.argv[command]) == "init":
 elif str(sys.argv[command]) == "stop":
     pass  # running = False
 
-print("Command invalid or invalid arguments")
+elif str(sys.argv[command]) == "--help" or str(sys.argv[command]) == "-h":
+    sys.stdout = sys.__stdout__
+    print("""
+Usage:  uacs [OPTIONS] COMMAND [ARGUMENT]
+
+Options:
+  -v, --verbose    Shows more details on what the command does
+
+Commands:
+  restore          Restore Email and Service
+  restore_service  Restore Services
+  restore_email    Restore Email and Email's password
+  init             Init UACS
+  send_mail        Sends mail when a service crashes
+  start            Force run uacs
+  append           Append new service
+  -h, --help       Shows this message
+  stop             Stop all background scripts
+
+Run 'uacs COMMAND --help' for more information on a command.
+""")
+
+exit(0)
